add_linspace_outliers — skchange

Skip to main content
`Ctrl`+`K`

# add_linspace_outliers

add_linspace_outliers(df, n_outliers, outlier_size)

  Add outliers to a DataFrame at evenly spaced positions.

  Parameters:
    dfpd.DataFrame

      DataFrame to add outliers to.

    n_outliersint

      Number of outliers to add.

    outlier_sizefloat

      Size of the outliers.

  Returns:
    pd.DataFrame

      DataFrame with outliers added.